@@ -1,12 +1,16 @@
 """
-## Amazon Simple Email Service Actions Library
+# Amazon Simple Email Service Actions Library
 
 <!--BEGIN STABILITY BANNER-->---
 
 
 ![cdk-constructs: Experimental](https://img.shields.io/badge/cdk--constructs-experimental-important.svg?style=for-the-badge)
 
-> The APIs of higher level constructs in this module are experimental and under active development. They are subject to non-backward compatible changes or removal in any future version. These are not subject to the [Semantic Versioning](https://semver.org/) model and breaking changes will be announced in the release notes. This means that while you may use them, you may need to update your source code when upgrading to a newer version of this package.
+> The APIs of higher level constructs in this module are experimental and under active development.
+> They are subject to non-backward compatible changes or removal in any future version. These are
+> not subject to the [Semantic Versioning](https://semver.org/) model and breaking changes will be
+> announced in the release notes. This means that while you may use them, you may need to update
+> your source code when upgrading to a newer version of this package.
 
 ---
 <!--END STABILITY BANNER-->
@@ -57,7 +61,7 @@ class AddHeader(
     def __init__(self, *, name: builtins.str, value: builtins.str) -> None:
         """
         :param name: (experimental) The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
-        :param value: (experimental) The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\r" or "\n").
+        :param value: (experimental) The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\\r" or "\\n").
 
         :stability: experimental
         """
@@ -89,7 +93,7 @@ class AddHeaderProps:
         """(experimental) Construction properties for a add header action.
 
         :param name: (experimental) The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
-        :param value: (experimental) The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\r" or "\n").
+        :param value: (experimental) The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\\r" or "\\n").
 
         :stability: experimental
         """
@@ -117,7 +121,7 @@ class AddHeaderProps:
         """(experimental) The value of the header to add.
 
         Must be less than 2048 characters,
-        and must not contain newline characters ("\r" or "\n").
+        and must not contain newline characters ("\\r" or "\\n").
 
         :stability: experimental
         """
